@@ -253,6 +253,16 @@ def _PyScript(env, target, source, command = "python $SOURCES", capture=None, ex
         os.chmod(exe, 0755)
         file.close()
 
+        ts = os.path.join(basename, "TARGETS")
+        file = open(ts, 'w')
+        print >>file, "\n".join(target)
+        file.close()
+
+        ss = os.path.join(basename, "SOURCES")
+        file = open(ss, 'w')
+        print >>file, "\n".join(source + [scons, exe, ss, ts])
+        file.close()
+
         if not lightweight: command = exe + " -Q"
 
     if execute: command = execute + " " + basename
@@ -283,7 +293,7 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q", sig_options
     if USE_DIR in _USED_DIRS: raise ValueError("Cannot use temp directory %s in more than one PyScript or PyScons." % basename)
     else: _USED_DIRS.add(USE_DIR)
 
-    vars = " temp=" + basename + " n=" + scons  
+    vars = " temp=" + basename + " n=" + scons
 
     if not os.path.exists(basename): mkdir_p(basename)
     exe = os.path.join(basename, "EXECUTE")
@@ -292,6 +302,16 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q", sig_options
     os.chmod(exe, 0755)
     file.close()
 
+    ts = os.path.join(basename, "TARGETS")
+    file = open(ts, 'w')   
+    print >>file, "\n".join(target)
+    file.close()   
+
+    ss = os.path.join(basename, "SOURCES")
+    file = open(ss, 'w')   
+    print >>file, "\n".join(source + [scons, ts, ss, exe])
+    file.close()
+
     cmd = exe + " " + options
     cleancmd = cmd + " --clean"
 
